In-memory Transport - kombu.transport.memory — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# In-memory Transport - kombu.transport.memory

class `kombu.transport.memory.` `Channel`(connection, **kwargs)

class `kombu.transport.memory.` `Transport`(client, **kwargs)
  class `Channel`(connection, **kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »